@@ -4,12 +4,13 @@ import numpy as np
 def discrete_draw(p):
     # samples a discrete number based on a vector of probabilities
     probs = [float(z) / sum(p) for z in p]
-    rv = np.random.multinomial(1, probs)
+    # rv = np.random.multinomial(1, probs)
     return int(np.where(np.random.multinomial(1, probs) == 1)[0])
 
 
 def Restricted_Crp(alpha, previous_counts, previous_ms2, len_current_ms2):
-    # Draws a value from a Chinese Restaurant process, but excludes values already part of the current sample
+    # Draws a value from a Chinese Restaurant process, but excludes
+    # values already part of the current sample
     n = len(previous_ms2)
     if previous_ms2 == []:
         return 0, [1]
